Traits
- Clerpable
- Cycle
Stapable - Deki
ExtF32 - This is an extension trait for the following impl:
- Glerpable
- Any type that implements necessary math traits for linear interpolation (lerp)
- Lerpable
- Any type that implemients necessary math traits for linear interpolation (lerp)
- Lerpable
F32 - Any type that implemients necessary math traits for linear interpolation (lerp)
- Stepable